#include "project.h"

#include <stdbool.h>
#include <stdio.h>
#include <string.h>

#include "spi_dma.h"

#define ARRAY_SIZE(x) (sizeof(x) / sizeof(x[0]))
#define SET_ARRAY_TO_ZERO(x, size)                                             \
    do {                                                                       \
        for (uint8_t i = 0; i < size; i++) {                                   \
            x[i] = 0;                                                          \
        }                                                                      \
    } while (0);

enum { MAX_ARRAY_SIZE = 32 };
enum { FEED_FORM_CMD = 0xC };

void print_array(const uint8_t *data, const size_t size);

int main(void)
{
    const uint8_t data_send[MAX_ARRAY_SIZE] = {
        0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08,
        0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08,
        0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08,
        0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08 };

    uint8_t data_get[MAX_ARRAY_SIZE] = {0};

    CyGlobalIntEnable;

    UART_Start();
    SPI_Start();

    UART_PutChar(FEED_FORM_CMD); // clear the screen
    UART_PutString("\t\tTest transfer memory->SPI with DMA\r\n");

    // transfer with configurable DMA
    UART_PutString("\r\nTransfering via configurable DMA...\r\n");
    send_spi_dma(data_send, data_get, ARRAY_SIZE(data_get));

    // printing results
    UART_PutString("\r\nRe configurable DMA transfer done!\r\n");
    UART_PutString("Printing the source array\r\n");
    print_array(data_send, ARRAY_SIZE(data_send));
    UART_PutString("Printing the destination array\r\n");
    print_array(data_get, ARRAY_SIZE(data_get));

    // setting array to zero
    UART_PutString("Setting the destination array to zero\r\n");
    SET_ARRAY_TO_ZERO(data_get, ARRAY_SIZE(data_get));
    UART_PutString("Printing the destination array\r\n");
    print_array(data_get, ARRAY_SIZE(data_get));
    
    UART_PutString("\r\nTransfering just 5 bytes via configurable DMA...\r\n");
    send_spi_dma(data_send, data_get, 5);

    // printing results
    UART_PutString("\r\nRe configurable DMA transfer done!\r\n");
    UART_PutString("\r\nPrinting the source array\r\n");
    print_array(data_send, 5);
    UART_PutString("\r\nPrinting the destination array\r\n");
    print_array(data_get, 5);

    while (1) {
        send_spi_dma(data_send, data_get, MAX_ARRAY_SIZE);
        CyDelay(10);
        send_spi_dma(data_send, data_get, 5);
        CyDelay(10);
        send_spi_dma(data_send, data_get, 10);
        CyDelay(10);
    }
}

void print_array(const uint8_t *data, const size_t size) {
  for (uint8_t i = 0; i < size; i++) {
    UART_PutHexByte(data[i]);
    UART_PutString(", ");
    /* new line every 8th printed element */
    if ((15 == i) | (31 == i)) {
      UART_PutString("\r\n");
    }
  }
}

/* [] END OF FILE */
