#include "project.h"
#include "spi_dma.h"

void send_spi_dma(const uint8_t* tx_data, uint8_t* rx_data, const size_t size)
{    
    const uint8_t DMA_REQUEST_PER_BURST = 1;
    const uint8_t DMA_BYTES_PER_BURST = 1;
    uint8_t DMA_Rx_Chan = 0;
    uint8_t DMA_Tx_Chan = 0;
    uint8_t DMA_Rx_TD[1] = {0};
    uint8_t DMA_Tx_TD[1] = {0};
    
    // disable the DMAs before reconfiguring them
    //CyDmaChDisable(DMA_Rx_Chan);
    //CyDmaChDisable(DMA_Tx_Chan);

    // Allocate DMA Channels
    DMA_Rx_Chan = DMA_Rx_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST,
                                        HI16(CYDEV_PERIPH_BASE), HI16(CYDEV_SRAM_BASE));
    
    DMA_Tx_Chan = DMA_Tx_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST,
                                        HI16(CYDEV_SRAM_BASE), HI16(CYDEV_PERIPH_BASE));
    
    // Allocate TDs
    DMA_Rx_TD[0] = CyDmaTdAllocate();
    DMA_Tx_TD[0] = CyDmaTdAllocate();

    CyDmaTdSetConfiguration(DMA_Rx_TD[0], size, CY_DMA_DISABLE_TD, CY_DMA_TD_INC_DST_ADR);
    CyDmaTdSetConfiguration(DMA_Tx_TD[0], size, CY_DMA_DISABLE_TD, CY_DMA_TD_INC_SRC_ADR);
    
    CyDmaTdSetAddress(DMA_Rx_TD[0], LO16((uint32)SPI_RXDATA_PTR), LO16((uint32)&rx_data[0]));
    CyDmaTdSetAddress(DMA_Tx_TD[0], LO16((uint32)&tx_data[0]), LO16((uint32)SPI_TXDATA_PTR));
    
    CyDmaChSetInitialTd(DMA_Rx_Chan, DMA_Rx_TD[0]);
    CyDmaChSetInitialTd(DMA_Tx_Chan, DMA_Tx_TD[0]);

    // enable the DMAs
    CyDmaChEnable(DMA_Rx_Chan, 1);
    CyDmaChEnable(DMA_Tx_Chan, 1);

    // Waiting for the /SS to go high
    // UART_PutString("Waiting for the SPI to be done\r\n");
    while(0 == (SPI_ReadTxStatus() & SPI_STS_SPI_DONE)) {
    }
    
    /* Freeing the DMA Channel and TDs */
    CyDmaChDisable(DMA_Rx_Chan);
    CyDmaChDisable(DMA_Tx_Chan);
    
    CyDmaTdFree(DMA_Rx_TD[0]);
    CyDmaTdFree(DMA_Tx_TD[0]);
}

/* [] END OF FILE */
